@@ -1,7 +1,7 @@
 /* Setcd.c: Set various flags to control the behaviour of your cdrom device.
    (c) 1997 David A. van Leeuwen
 
-   $Id: setcd.c,v 1.2 1997/11/18 21:12:48 david Exp $
+   $Id: setcd.c,v 1.3 1998/11/16 22:27:21 david Exp $
 
      This program is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -25,11 +25,13 @@
 #include <unistd.h>		/* lseek, read */
 #include <string.h>		/* strncmp */
 #include <sys/ioctl.h>		/* ioctl */
-#include <linux/ucdrom.h>
 #include <linux/cdrom.h>
+#ifndef CDC_CLOSE_TRAY		/* moved into cdrom.h... */
+#include <linux/ucdrom.h>
+#endif
 #include <linux/iso_fs.h>
 
-#define REVISION "$Revision: 1.2 $"
+#define REVISION "$Revision: 1.3 $"
 
 void usage(FILE * f, char * s) 
 {
@@ -120,6 +122,7 @@ void print_info(int fd)
      int status = ioctl(fd, CDROM_DRIVE_STATUS, 0);
      if (status<0) {
 	  perror("can't read drive status");
+	  fprintf(stderr, "%d\n", status);
 	  exit (-8);
      }
      switch(status) {
@@ -138,8 +141,16 @@ void print_info(int fd)
      case CDS_DISC_OK:
 	  printf("  Disc found in drive:");
 	  status=ioctl(fd,  CDROM_DISC_STATUS);
-	  if (status < 0) break;
+	  if (status < 0) {
+	       fprintf(stderr, "%d\n", status);
+	       break;
+	  }
 	  switch (status) {
+	  case CDS_MIXED:
+	       printf(" mixed type CD (data/audio)\n");
+	       print_audio_info(fd);
+	       print_data_info(fd);
+	       break;
 	  case CDS_AUDIO:
 	       printf(" audio disc\n");
 	       print_audio_info(fd);
@@ -152,9 +163,10 @@ void print_info(int fd)
 	  case CDS_XA_2_1:
 	  case CDS_XA_2_2:
 	       printf(" XA data disc type %d\n", status-CDS_XA_2_1+1);
+	       print_data_info(fd);
 	       break;
 	  default:
-	       printf("\n");
+	       printf("Unknown status %d\n", status);
 	  }
 	  break;
      default:
